@@ -47,6 +47,7 @@ class QemuDevice(Device):
         overlays,
         parameters,
         partition,
+        prompt,
         rootfs,
         tests,
         **kwargs,
@@ -64,6 +65,8 @@ class QemuDevice(Device):
             )
         if boot_args and '"' in boot_args:
             raise InvalidArgument('argument --boot-args should not contains "')
+        if prompt and '"' in prompt:
+            raise InvalidArgument('argument --prompt should not contains "')
         if dtb and self.name != "qemu-armv5":
             raise InvalidArgument("argument --dtb is only valid for qemu-armv5 device")
         if modules and compression(modules) not in [("tar", "gz"), ("tar", "xz")]:
@@ -100,6 +103,11 @@ class QemuDevice(Device):
                 kwargs["tux_boot_args"] = ""
             kwargs["tux_boot_args"] += self.extra_boot_args
 
+        if kwargs["tux_prompt"]:
+            kwargs["tux_prompt"] = [kwargs["tux_prompt"]]
+        else:
+            kwargs["tux_prompt"] = []
+
         # render the template
         tests = [
             t.render(
@@ -112,11 +120,9 @@ class QemuDevice(Device):
             )
             for t in kwargs["tests"]
         ]
-        return (
-            templates.jobs().get_template("qemu.yaml.jinja2").render(**kwargs)
-            + "\n"
-            + "".join(tests)
-        )
+        return templates.jobs().get_template("qemu.yaml.jinja2").render(
+            **kwargs
+        ) + "".join(tests)
 
     def device_dict(self, context):
         if self.test_character_delay:
